@@ -6,29 +6,29 @@ use std::{
     process,
 };
 
+use clap::Parser;
 use jsonschema::JSONSchema;
-use structopt::StructOpt;
 
 type BoxErrorResult<T> = Result<T, Box<dyn Error>>;
 
-#[derive(Debug, StructOpt)]
-#[structopt(name = "jsonschema")]
+#[derive(Parser)]
+#[command(name = "jsonschema")]
 struct Cli {
     /// A path to a JSON instance (i.e. filename.json) to validate (may be specified multiple times).
-    #[structopt(short = "i", long = "instance")]
+    #[arg(short = 'i', long = "instance")]
     instances: Option<Vec<PathBuf>>,
 
     /// The JSON Schema to validate with (i.e. schema.json).
-    #[structopt(parse(from_os_str), required_unless("version"))]
+    #[arg(value_parser, required_unless_present("version"))]
     schema: Option<PathBuf>,
 
     /// Show program's version number and exit.
-    #[structopt(short = "v", long = "version")]
+    #[arg(short = 'v', long = "version")]
     version: bool,
 }
 
 pub fn main() -> BoxErrorResult<()> {
-    let config = Cli::from_args();
+    let config = Cli::parse();
 
     if config.version {
         println!(concat!("Version: ", env!("CARGO_PKG_VERSION")));
