@@ -20,13 +20,13 @@ pub enum PrimitiveType {
 impl fmt::Display for PrimitiveType {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            PrimitiveType::Array => write!(f, "array"),
-            PrimitiveType::Boolean => write!(f, "boolean"),
-            PrimitiveType::Integer => write!(f, "integer"),
-            PrimitiveType::Null => write!(f, "null"),
-            PrimitiveType::Number => write!(f, "number"),
-            PrimitiveType::Object => write!(f, "object"),
-            PrimitiveType::String => write!(f, "string"),
+            PrimitiveType::Array => f.write_str("array"),
+            PrimitiveType::Boolean => f.write_str("boolean"),
+            PrimitiveType::Integer => f.write_str("integer"),
+            PrimitiveType::Null => f.write_str("null"),
+            PrimitiveType::Number => f.write_str("number"),
+            PrimitiveType::Object => f.write_str("object"),
+            PrimitiveType::String => f.write_str("string"),
         }
     }
 }
@@ -118,7 +118,7 @@ impl IntoIterator for PrimitiveTypesBitMap {
     type IntoIter = PrimitiveTypesBitMapIterator;
     fn into_iter(self) -> Self::IntoIter {
         PrimitiveTypesBitMapIterator {
-            range: 0..7,
+            idx: 0,
             bit_map: self,
         }
     }
@@ -137,23 +137,21 @@ impl From<Vec<PrimitiveType>> for PrimitiveTypesBitMap {
 /// Iterator over all `PrimitiveType` present in a `PrimitiveTypesBitMap`
 #[derive(Debug)]
 pub struct PrimitiveTypesBitMapIterator {
-    range: std::ops::Range<u8>,
+    idx: u8,
     bit_map: PrimitiveTypesBitMap,
 }
 impl Iterator for PrimitiveTypesBitMapIterator {
     type Item = PrimitiveType;
     #[allow(clippy::integer_arithmetic)]
     fn next(&mut self) -> Option<Self::Item> {
-        loop {
-            if let Some(value) = self.range.next() {
-                let bit_value = 1 << value;
-                if self.bit_map.inner & bit_value != 0 {
-                    return Some(bit_map_representation_primitive_type(bit_value));
-                }
-            } else {
-                return None;
+        while self.idx <= 7 {
+            let bit_value = 1 << self.idx;
+            self.idx += 1;
+            if self.bit_map.inner & bit_value != 0 {
+                return Some(bit_map_representation_primitive_type(bit_value));
             }
         }
+        None
     }
 }
 
